@@ -27,13 +27,10 @@ from .PTE_config import db_config
 class enrichment_result:
     def __init__(self):
 
-        print(f'Enrichment: {os.getcwd()}')
-
         self.query_gene_set = set()
         self.miss_id_set = set()
 
         #m: Total number of target objects / Number of genes in query gene set (Need to subtract the number
-        #                                                     of genes not in the background data)
         self.terms_count = defaultdict(int)
 
         # Statistics of each concept
