@@ -5,27 +5,21 @@ Created on 14/07/2020 下午11:48
 @Author: xinzhi yao
 """
 
-import os
+import inspect, os
 
-print(f'PTECONFIG: {os.getcwd()}')
 
-# todo: convert the config file to bash format.
+def get_script_path():
+    script_file = inspect.getfile(inspect.currentframe())
+    return os.path.abspath(os.path.dirname(script_file))
+
+script_path = get_script_path()
+print(script_path)
+
 db_config = {
     'db_path': 'data',
     'ontology_file': f'data/to.wto.ro.funRiceGene.obo',
     'ontology_url': 'https://raw.githubusercontent.com/YaoXinZhi/Plant-Trait-Enrichment/master/data/to-basic.obo',
-    # 'PT_anno_file': '../data/Oryzasebase.txt',
     'PT_anno_file': f'data/Total_Association.txt',
     'PT_anno_url': 'https://raw.githubusercontent.com/YaoXinZhi/Plant-Trait-Enrichment/master/data/Oryzasebase.txt',
 
-    'evidence_file': '',
-
-    # data source
-
-
-}
-
-# background
-bg_config = {
-    'id_type': ['rap', 'msu', 'gramene'],
 }
